;
;
; =============================================================================
;
;   MC9S08xxx SCI Include File
;                                 
;   Version:       1.0   Updated 12/04/2005
;   Author:        Spencer Ruggles , Axiom Mfg.
;   Compiler:
;       
;   Platform:		
;   Purpose:       MC9S08xxx SCI Routines
; =============================================================================
;
; Callable routines include:
; ONSCI		setup SCI 
; OUTCHAR	send a character of data 
; OUTSTRG	send a string of data
; CRLF		start a new line
; CRLF2		send a blank line

; ==================== COM Routines ===========================================

; Baud rate set by SBR[12:0] in SCIBDH:SCIBDL.  
; SCIBR = BUSCLK/(16*SBR[12:0])
; Setup BUSCLK before calling ONSCI routine.  Pass in baud rate and control
; register values from calling program

ONSCI:                                 ; enable SCI 
         mov #BDH,SCIBDH               ; high baud rate value
         mov #BDL,SCIBDL               ; low baud rate value
         mov #SC2,SCIC2                ; TxDA, RxDA en
         mov #SC1,SCIC1                ; 8,N,1
         mov #SC3,SCIC3                ; default
         ldhx #$0fff                   ; init count
SDLY:    aix #-1                       ; dec X
         cphx #$0000                   ; update CCR
         bne SDLY                      ; delay loop to let SCI catch up 
         rts                           ; return
	

CRLF:                                  ; send CR/LF to terminal
         lda #$0A                      ; get LF
         jsr OUTCHAR                   ; send it
         lda #$0D                      ; get CR
         jsr OUTCHAR                   ; send it
         rts                           ; return


OUTCHAR:                               ; send char in A to terminal
         brclr 7,SCIS1,OUTCHAR         ; loop until SCTE bit clr
         and #$7F                      ; mask parity
         sta SCID                      ; send char
         rts                           ; return


OUTSTRG:                               ; output a string to SCI
         lda ,X                        ; load char to A
         cmp #EOT                      ; last char?
         beq XOSTR                     ; exit if EOT char
         jsr OUTCHAR                   ; send char to terminal
         aix #1                        ; point to next char
         bra OUTSTRG                   ; send next char
XOSTR:	
         jsr CRLF
         rts

CRLF2:                                 ; output blank line
         jsr CRLF                      ; send CR/LF
         jsr CRLF                      ; send CR/LF
         jsr CRLF                      ; send CR/LF
         rts
	
GCHAR:
         brclr 5,SCIS1,GCHAR           ; loop until RDRF set
         lda SCID                      ; input char in A
         rts
	
