;*******************************************************************
;* This stationery serves as the framework for a user application. *
;* For a more comprehensive program that demonstrates the more     *
;* advanced functionality of this processor, please see the        *
;* demonstration applications, located in the examples             *
;* subdirectory of the "Freescale CodeWarrior for HC08" program    *
;* directory.                                                      *
;*******************************************************************

; Include derivative-specific definitions
            INCLUDE 'derivative.inc'

; export symbols
            XDEF _Startup, main
            ; we export both '_Startup' and 'main' as symbols. Either can
            ; be referenced in the linker .prm file or from C/C++ later on

            XREF __SEG_END_SSTACK      ; symbol defined by the linker for the end of the stack


; variable/data section
MY_ZEROPAGE: SECTION  SHORT            ; Insert here your data definition

BDH:          equ $00                  ; SCI Baud Rate High value
BDL:          equ $36                  ; SCI Baud Rate Low value - 9600 bps
SC1:          equ $00                  ; SCI CR1 value
SC2:          equ $0C                  ; SCI CR2 value, 8,1,N
SC3:          equ $00                  ; SCI CR3 value

CH0SU:        equ $20                  ; config for cont conv, ch0
CH1SU:        equ $21                  ; config for cont conv, ch1

TLO:          equ $33                  ; lower trigger value
THI:          equ $E0                  ; upper trigger value

EOT:          equ $04                  ; end of text char
RDRF:         equ $20                  ; Rx Data Ready Flag


; code section
MyCode:     SECTION
main:
_Startup:
         sei                           ; mask interrupts	
         ldhx #__SEG_END_SSTACK        ; H:X points to top of RAM
         txs                           ; init SP
         ldhx #SOPT1                   ; H:X points to SOPT1
         clra		
         sta ,X                        ; COP dis,

;******************************************************************************
; Use default FEI mode
; FBUS = 4.193Mhz
; ISCC1 and ICSC2 use default values
;******************************************************************************

         mov #$03,PTCD                 ; init PTC[1:0]
         mov #$03,PTCDD                ; PTC[1:0] output

         jsr ONSCI                     ; 9600,8,1,N
         jsr TMENU                     ; display test menu

FT:
         ldhx #PB1P                    ; get text
         jsr OUTSTRG                   ; send it out
PB1:
         brset 2,PTAD,PB1              ; loop until PB1 pressed
         jsr LED1                      ; toggle LED1 

         ldhx #PB2P                    ; get text 
         jsr OUTSTRG                   ; send it out
PB2:
         brset 3,PTAD,PB2              ; loop until PB[2] pressed
         jsr LED2                      ; toggle LED2

;******************************************************************************
;
; Configure ADC to test POT (RV1) and Sensor (RZ1)
; ADC setup for SW trigger, continuous conversion, 8-bit results
;  
;******************************************************************************

         mov #$0,ADCCFG                ; 8 bit, bus clk, divide by 1
         mov #$03,APCTL1               ; en P1, P0 ADC input
         mov #$10,ADCSC2               ; SW trigger
         mov #CH0SU,ADCSC1             ; cont conversion, Ch0
         ldhx #RVCW                    ; get text
         jsr OUTSTRG                   ; send it out
	
RVL:
         lda ADCRL                     ; get ADC results
         cmp #TLO                      ; compare to low value
         bhi RVL                       ; loop if input < compare value
         ldhx #RVCCW                   ; get text
         jsr OUTSTRG                   ; send it out	

RVH:
         lda ADCRL                     ; get ADC results
         cmp #THI                      ; compare to hi value
         blo RVH                       ; loop if input > compare value
         ldhx #SENC                    ; get text
         jsr OUTSTRG                   ; send it out
         mov #CH1SU,ADCSC1             ; cont conversion, CH1

         jsr DELAY                     ; wait 

SENH:
         lda ADCRL                     ; get ADC results
         cmp #THI                      ; compare to hi value
         blo SENH                      ; loop if input > compare value
	
         ldhx #SENU                    ; get text
         jsr OUTSTRG                   ; send it out
SENL:
         lda ADCRL                     ; get ADC results
         cmp #TLO                      ; compare to low value
         bhi SENL                      ; loop if input < compare value
	
         ldhx #COMP                    ; get text
         jsr OUTSTRG                   ; send it out

END:
         bra END

; ===================== Sub-Routines ==========================================

DELAY:
         ldhx #$00ff                   ; inner loop delay count
DLY1:
         aix #-1                       ; decrement H:X 
         cphx #$0000                   ; update CCR
         bne DLY1                      ; inner loop
         rts                           ; return

LED1:
         ldhx #PTCD                    ; PTC addr
         lda ,X                        ; read PTC
         eor #$20                      ; neg PTC[5]
         sta PTCD                      ; write PTC
         rts                           ; return
		
LED2:
         ldhx #PTBD                    ; PTB addr
         lda ,X                        ; read PTC
         eor #$08                      ; neg PTB[3]
         sta PTBD                      ; write PTB
         rts                           ; return
                 

; ===================== Include Files =========================================

	       include 'EL32Menu.asm'	       ; menu sub-routines
	       include '9S08SCI.inc'	       ; 9S08 SCI routines
